@@ -256,18 +256,11 @@ BjoJZJZQztmlj7Qep/sf1l8=
     // from https://tools.ietf.org/html/draft-ietf-curdle-pkix-07#section-10.1
     public function testEd25519PublicKey()
     {
-        $key = PublicKeyLoader::load('-----BEGIN PUBLIC KEY-----
-MCowBQYDK2VwAyEAGb9ECWmEzf6FQbrBZ9w7lshQhqowtrbLDFw4rXAxZuE=
------END PUBLIC KEY-----');
-        $this->assertSameNL('Ed25519', $key->getCurve());
-
-        // in the above key AlgorithmIdentifier has a single "child". in the
-        // following key it has two. The second one is ("optional") NULL.
-        // https://security.stackexchange.com/q/110330/15922 elaborates on
-        // why phpseclib is encoding the NULL as opposed to omitting it.
         $expected = '-----BEGIN PUBLIC KEY-----
-MCwwBwYDK2VwBQADIQAZv0QJaYTN/oVBusFn3DuWyFCGqjC2tssMXDitcDFm4Q==
+MCowBQYDK2VwAyEAGb9ECWmEzf6FQbrBZ9w7lshQhqowtrbLDFw4rXAxZuE=
 -----END PUBLIC KEY-----';
+        $key = PublicKeyLoader::load($expected);
+        $this->assertSameNL('Ed25519', $key->getCurve());
         $this->assertSameNL($expected, $key->toString('PKCS8'));
     }
 
@@ -572,4 +565,109 @@ MIIEDwIBADATBgcqhkjOPQIBBggqhkjOPQMBBwSCA/MwggPvAgEBBIID6P//////
 
         $this->assertSameNL($raw, $key->toString('MontgomeryPrivate'));
     }
+
+    public function testOpenSSHEncryptedCreation()
+    {
+        if (PHP_INT_SIZE == 4) {
+            self::markTestSkipped('32-bit integers slow OpenSSH encrypted keys down too much');
+        }
+
+        $key = EC::createKey('Ed25519');
+        $key = $key->withPassword('test')->toString('OpenSSH');
+
+        $key = PublicKeyLoader::load($key, 'test');
+        $this->assertInstanceOf(PrivateKey::class, $key);
+    }
+
+    public function testECasJWK()
+    {
+        // keys are from https://datatracker.ietf.org/doc/html/rfc7517#appendix-A
+
+        $plaintext = 'zzz';
+
+        $key = '     {"keys":
+       [
+         {"kty":"EC",
+          "crv":"P-256",
+          "x":"MKBCTNIcKUSDii11ySs3526iDZ8AiTo7Tu6KPAqv7D4",
+          "y":"4Etl6SRW2YiLUrN5vfvVHuhp7x8PxltmWWlbbM4IFyM",
+          "d":"870MB6gfuTJ4HtUnUvYMyJpr5eUZNP4Bk43bVdj3eAE",
+          "use":"enc",
+          "kid":"1"}
+       ]
+     }';
+
+        $keyWithoutWS = preg_replace('#\s#', '', $key);
+
+        $key = PublicKeyLoader::load($key);
+
+        $phpseclibKey = str_replace('=', '', $key->toString('JWK', [
+            'use' => 'enc',
+            'kid' => '1'
+        ]));
+
+        $this->assertSame($keyWithoutWS, $phpseclibKey);
+
+        $sig = $key->sign($plaintext);
+
+        $key = '{"keys":
+       [
+         {"kty":"EC",
+          "crv":"P-256",
+          "x":"MKBCTNIcKUSDii11ySs3526iDZ8AiTo7Tu6KPAqv7D4",
+          "y":"4Etl6SRW2YiLUrN5vfvVHuhp7x8PxltmWWlbbM4IFyM",
+          "use":"enc",
+          "kid":"1"}
+       ]
+     }';
+
+        $keyWithoutWS = preg_replace('#\s#', '', $key);
+
+        $key = PublicKeyLoader::load($key);
+
+        $phpseclibKey = str_replace('=', '', $key->toString('JWK', [
+            'use' => 'enc',
+            'kid' => '1'
+        ]));
+
+        $this->assertSame($keyWithoutWS, $phpseclibKey);
+
+        $this->assertTrue($key->verify($plaintext, $sig));
+    }
+
+    public function testEd25519asJWK()
+    {
+        // keys are from https://www.rfc-editor.org/rfc/rfc8037.html#appendix-A
+
+        $plaintext = 'zzz';
+
+        $key = '   {"kty":"OKP","crv":"Ed25519",
+   "x":"11qYAYKxCrfVS_7TyWQHOg7hcvPapiMlrwIaaPcHURo",
+   "d":"nWGxne_9WmC6hEr0kuwsxERJxWl7MmkZcDusAxyuf2A"}';
+
+        $keyWithoutWS = preg_replace('#\s#', '', $key);
+        $keyWithoutWS = '{"keys":[' . $keyWithoutWS . ']}';
+
+        $key = PublicKeyLoader::load($key);
+
+        $phpseclibKey = str_replace('=', '', $key->toString('JWK'));
+
+        $this->assertSame($keyWithoutWS, $phpseclibKey);
+
+        $sig = $key->sign($plaintext);
+
+        $key = '   {"kty":"OKP","crv":"Ed25519",
+   "x":"11qYAYKxCrfVS_7TyWQHOg7hcvPapiMlrwIaaPcHURo"}';
+
+        $keyWithoutWS = preg_replace('#\s#', '', $key);
+        $keyWithoutWS = '{"keys":[' . $keyWithoutWS . ']}';
+
+        $key = PublicKeyLoader::load($key);
+
+        $phpseclibKey = str_replace('=', '', $key->toString('JWK'));
+
+        $this->assertSame($keyWithoutWS, $phpseclibKey);
+
+        $this->assertTrue($key->verify($plaintext, $sig));
+    }
 }
